@@ -56,7 +56,7 @@
 #'   \item{ymax}{data$y maximum}
 #'   \item{yint}{data$y integral for each mebmer of w.band / sum of data$y
 #'   integrals for all wavebands in w.band}
-#'   \item{xmean}{yint divided by spread(w.band)}
+#'   \item{xmean}{yint divided by wl_expanse(w.band)}
 #'   \item{y}{ypos.fixed or top of data, adjusted by \code{ypos.mult}}
 #'   \item{wb.color}{color of the w.band}
 #'   \item{wb.name}{label of w.band}
@@ -176,7 +176,7 @@ StatWbRelative <-
                          wb <- waveband(wb)
                        }
                        yint.tmp <- integral.fun(mydata$x, mydata$y)
-                       ymean.tmp <- yint.tmp / spread(wb)
+                       ymean.tmp <- yint.tmp / wl_expanse(wb)
                        integ.df <- rbind(integ.df,
                                          data.frame(x = midpoint(mydata$x),
                                                     xmin = min(wb),
